@@ -6,7 +6,7 @@ from vk_api.longpoll import VkEventType, VkLongPoll
 
 from quiz_bots import settings
 from quiz_bots.bots_helpers import (
-    Button,
+    BotKeyboardButton,
     make_keyboard_of_vk,
     send_message_to_vk_chat,
 )
@@ -23,32 +23,32 @@ from quiz_bots.redis_utils import (
 REDIS_CONNECTION = connect_to_redis()
 QUIZ_CONTENT = get_quiz_content_from_redis(REDIS_CONNECTION)
 
-BUTTON_NEW_QUESTION = Button(text='Новый вопрос', color=VkKeyboardColor.PRIMARY)
-BUTTON_SURRENDER = Button(text='Сдаться', color=VkKeyboardColor.NEGATIVE)
-BUTTON_SCORE = Button(text='Мой счет', color=VkKeyboardColor.POSITIVE)
-QUESTION_IS_SET_INCORRECTLY_BUTTON = Button(text='Вопрос составлен неверно', color=VkKeyboardColor.DEFAULT)
+BUTTON_NEW_QUESTION = BotKeyboardButton(text='Новый вопрос', color=VkKeyboardColor.PRIMARY)
+BUTTON_GIVE_IN = BotKeyboardButton(text='Сдаться', color=VkKeyboardColor.NEGATIVE)
+BUTTON_SCORE = BotKeyboardButton(text='Мой счет', color=VkKeyboardColor.POSITIVE)
+BUTTON_QUESTION_IS_MADE_INCORRECTLY = BotKeyboardButton(text='Вопрос составлен неверно', color=VkKeyboardColor.DEFAULT)
 
 
-def handle_new_question_request(vk, event, is_clicked_surrender_button: float = False) -> None:
+def handle_new_question_request(vk, event, button_give_in_flag: float = False) -> None:
     """Sends a random question to the user."""
     question, number_of_question = get_random_question(QUIZ_CONTENT)
     user_id = event.user_id
 
-    if is_clicked_surrender_button:
-        top_buttons = [BUTTON_SURRENDER, BUTTON_SCORE]
-        bottom_buttons: Optional[List[Button]] = [QUESTION_IS_SET_INCORRECTLY_BUTTON]
+    if button_give_in_flag:
+        top_buttons = [BUTTON_GIVE_IN, BUTTON_SCORE]
+        bottom_buttons: Optional[List[BotKeyboardButton]] = [BUTTON_QUESTION_IS_MADE_INCORRECTLY]
     else:
-        top_buttons = [BUTTON_SURRENDER, BUTTON_SCORE]
+        top_buttons = [BUTTON_GIVE_IN, BUTTON_SCORE]
         bottom_buttons = None
 
     send_message_to_vk_chat(
-        social_network_api=vk,
+        vk_session=vk,
         user_id=user_id,
-        keyboard=make_keyboard_of_vk(
+        custom_keyboard=make_keyboard_of_vk(
             top_buttons=top_buttons,
             bottom_buttons=bottom_buttons,
         ),
-        message=question['question'].replace('\n', ' '),
+        message_text=question['question'].replace('\n', ' '),
     )
 
     save_last_asked_question_to_redis(
@@ -73,19 +73,19 @@ def handle_solution_attempt(vk, event) -> None:
     )
     if event.text.lower() == get_clean_text_of_answer(answer_to_last_question_of_user):
         top_buttons = [BUTTON_NEW_QUESTION]
-        message = 'Правильно! Для следующего вопроса нажми «Новый вопрос»'
+        message_text = 'Правильно! Для следующего вопроса нажми «Новый вопрос»'
     else:
-        top_buttons = [BUTTON_SURRENDER, BUTTON_SCORE]
-        message = 'Неправильно... Попробуешь ещё раз?'
+        top_buttons = [BUTTON_GIVE_IN, BUTTON_SCORE]
+        message_text = 'Неправильно... Попробуешь ещё раз?'
 
     send_message_to_vk_chat(
-        social_network_api=vk,
+        vk_session=vk,
         user_id=user_id,
-        keyboard=make_keyboard_of_vk(
+        custom_keyboard=make_keyboard_of_vk(
             top_buttons=top_buttons,
             bottom_buttons=None,
         ),
-        message=message,
+        message_text=message_text,
     )
 
 
@@ -106,23 +106,23 @@ def handle_opportunity_to_surrender(vk, event) -> None:
         last_asked_question=last_asked_question,
     )
     send_message_to_vk_chat(
-        social_network_api=vk,
+        vk_session=vk,
         user_id=user_id,
-        message=answer_to_last_question_of_user,
+        message_text=answer_to_last_question_of_user,
     )
-    handle_new_question_request(vk, event, is_clicked_surrender_button=True)
+    handle_new_question_request(vk, event, button_give_in_flag=True)
 
 
 def handler_question_is_incorrect(vk, event) -> None:
     """Handles clicking the button 'The question is incorrect'."""
     send_message_to_vk_chat(
-        social_network_api=vk,
+        vk_session=vk,
         user_id=event.user_id,
-        keyboard=make_keyboard_of_vk(
-            top_buttons=[BUTTON_SURRENDER, BUTTON_SCORE],
+        custom_keyboard=make_keyboard_of_vk(
+            top_buttons=[BUTTON_GIVE_IN, BUTTON_SCORE],
             bottom_buttons=None,
         ),
-        message='Спасибо за фидбек! Ждем ответ на предыдущий вопрос!',
+        message_text='Спасибо за фидбек! Ждем ответ на предыдущий вопрос!',
     )
 
 
